# benches

## Purpose
Micro-benchmarks for critical fast paths.

## Owns
- Route lookup benchmark.
- JSON serialization benchmark.

## Entry Points
- `cargo bench`

## Not Here
- Correctness tests (see `tests/`).
